Keyword

Enum Keyword 

pub enum Keyword {
Show 91 variants Create, Unique, Index, Global, Local, Table, View, Drop, Insert, Copy, Into, Values, Select, With, Recursive, From, Where, Order, By, Asc, Desc, Limit, And, Or, Not, True, False, Null, As, Begin, Start, Transaction, Commit, End, Rollback, Abort, Update, Set, Delete, Isolation, Level, Read, Committed, Repeatable, For, Share, Group, Having, Distinct, All, Is, In, Between, Like, Ilike, Case, When, Then, Else, Offset, Cast, Join, Inner, Left, Right, Full, Outer, Cross, On, Using, Natural, Exists, Any, Some, Union, Intersect, Except, Foreign, Data, Wrapper, Server, Mapping, User, Options, Import, Schema, To, If, CurrentUser, Public, Returning,
}

Variants



Create



Unique



Index



Global



Local



Table



View



Drop



Insert



Copy



Into



Values



Select



With



Recursive



From



Where



Order



By



Asc



Desc



Limit



And



Or



Not



True



False



Null



As



Begin



Start



Transaction



Commit



End



Rollback



Abort



Update



Set



Delete



Isolation



Level



Read



Committed



Repeatable



For



Share



Group



Having



Distinct



All



Is



In



Between



Like



Ilike



Case



When



Then



Else



Offset



Cast



Join



Inner



Left



Right



Full



Outer



Cross



On



Using



Natural



Exists



Any



Some



Union



Intersect



Except



Foreign



Data



Wrapper



Server



Mapping



User



Options



Import



Schema



To



If



CurrentUser



Public



Returning

Implementations